﻿/////////////////////////////////////////////////////////////////////////
//
// This module contains code to do a basic green screen.
//
// Copyright © Microsoft Corporation.  All rights reserved.  
// This code is licensed under the terms of the 
// Microsoft Kinect for Windows SDK (Beta) from Microsoft Research 
// License Agreement: http://research.microsoft.com/KinectSDK-ToU
//
/////////////////////////////////////////////////////////////////////////

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Microsoft.Research.Kinect.Nui;
using Coding4Fun.Kinect.Wpf; 

namespace CameraFundamentals
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        //Kinect Runtime
        Runtime nui = new Runtime(); 

        // Função chamada quando inicia a janela
        private void Window_Loaded(object sender, RoutedEventArgs e)
        {
            // Assim, as funções são chamadas aproximadamente 30vezes por segundo QUANDO estiver pronto os
            // frames de imagem RGB e de profundidade
            nui.VideoFrameReady += new EventHandler<ImageFrameReadyEventArgs>(nui_VideoFrameReady);
            nui.DepthFrameReady += new EventHandler<ImageFrameReadyEventArgs>(nui_DepthFrameReady);
            
            //Inicializar para que retorne tanto a informação de cor (UseColor), quanto a informação de profundidade (UseDepth)
            nui.Initialize(RuntimeOptions.UseColor | RuntimeOptions.UseDepth);

            //Abre os Streams
            nui.VideoStream.Open(ImageStreamType.Video, 2, ImageResolution.Resolution640x480, ImageType.Color);
            nui.DepthStream.Open(ImageStreamType.Depth, 2, ImageResolution.Resolution320x240, ImageType.Depth); 
        }

        void nui_DepthFrameReady(object sender, ImageFrameReadyEventArgs e)
        {
            //Usando o Extension Method para converter para Bitmap
            image2.Source = e.ImageFrame.ToBitmapSource(); 
        }

        void nui_VideoFrameReady(object sender, ImageFrameReadyEventArgs e)
        {
            // Criando manualmente a imagem 
            PlanarImage imageData = e.ImageFrame.Image;
            image1.Source = BitmapSource.Create(imageData.Width, imageData.Height, 96, 96, PixelFormats.Bgr32, null, imageData.Bits, imageData.Width * imageData.BytesPerPixel);
        }

        private void Window_Closed(object sender, EventArgs e)
        {
            nui.Uninitialize(); 
        }
    }
}
